@@ -255,3 +255,17 @@ def export_to_csv(df, name="default"):
     
 ## FUNCIONES CASO DE USO 3
 
+def popularity(sources, _from, _to):
+    """provides a list with all media outlets that currently have media outlets in Sun.
+
+    Returns:
+        [string]: [media_outlet]
+    """
+    pd.set_option("display.max_rows",None)
+    __connection_validator()
+    media_outlets=[]
+    for name in sources:
+        sql_vars["__cursor__"].execute("SELECT s.source_name, SUM(popularity_en), SUM(popularity_es), SUM(popularity_fr), SUM(popularity_it), SUM(popularity_pt), MONTH(popularity_date), YEAR(popularity_date) FROM has_popularity LEFT JOIN source s ON s.id_source = has_popularity.id_source WHERE s.source_name = ? AND popularity_date >= ? AND popularity_date <= ? GROUP BY MONTH(popularity_date), YEAR(popularity_date) ORDER BY (popularity_date)",(name,_from,_to))
+        for media_outlet in sql_vars["__cursor__"].fetchall():
+            media_outlets.append(media_outlet)
+    return pd.DataFrame(media_outlets,columns=["source","popularity_en","popularity_es","popularity_fr","popularity_it","popularity_pt", "month", "year"])
